@@ -1,4 +1,10 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
+BEGIN {
+  $Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.1';
+}
+BEGIN {
+  $Dist::Zilla::PluginBundle::GENEHACK::AUTHORITY = 'cpan:GENEHACK';
+}
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -17,7 +23,6 @@ use Dist::Zilla::Plugin::Bugtracker;
 use Dist::Zilla::Plugin::CompileTests;
 use Dist::Zilla::Plugin::EOLTests;
 use Dist::Zilla::Plugin::ExtraTests;
-use Dist::Zilla::Plugin::GitFmtChanges;
 use Dist::Zilla::Plugin::Git::NextVersion;
 use Dist::Zilla::Plugin::Homepage;
 use Dist::Zilla::Plugin::InstallGuide;
@@ -26,6 +31,7 @@ use Dist::Zilla::Plugin::KwaliteeTests;
 use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MinimumPerl;
+use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::PkgVersion;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::PodSyntaxTests;
@@ -41,7 +47,7 @@ sub configure {
 
   $self->add_plugins(
     # auto-versioning from git
-    [ 'Git::NextVersion' => { first_version => '0.01 '} ],
+    [ 'Git::NextVersion' => { first_version => '0.1' } ],
   );
 
   $self->add_bundle('Basic' );
@@ -52,6 +58,11 @@ sub configure {
     'AutoPrereqs' ,
   );
 
+  ## PLUGINS WHAT MAKE SURE WE DON'T LOOK STUPID
+  $self->add_plugins(
+    # does what it says on the tin
+    'CheckChangesHasContent' ,
+  );
 
   ## PLUGINS WHAT MUNGE CODE FILES
   $self->add_plugins(
@@ -92,14 +103,14 @@ sub configure {
 
   ## PLUGINS WHAT AUTO-GENERATE FILES
   $self->add_plugins(
-    # auto-generate CHANGES
-    'GitFmtChanges' ,
-
     # auto-make INSTALL
     'InstallGuide' ,
 
     # auto-generate a README
     'ReadmeFromPod' ,
+
+    # munge Changes
+    'NextRelease' ,
   );
 
   ## PLUGINS WHAT ADD TESTS
@@ -130,8 +141,6 @@ sub configure {
     # save released dists under ./releases
     'ArchiveRelease'
   );
-
-
 }
 
 1;
@@ -146,7 +155,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.04
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -155,7 +164,7 @@ this:
 
     [@Git]
     [Git::NextVersion]
-    first_version = 0.01
+    first_version = 0.1
 
     [@Basic]
 
@@ -163,6 +172,7 @@ this:
     [Authority]
     authority = 'cpan:GENEHACK'
     do_metadata = 1
+    [CheckChangesHasContent]
     [MinimumPerl]
     [PkgVersion]
     [PodWeaver]
@@ -172,7 +182,6 @@ this:
     [MetaJSON]
     [Repository]
     github_http = 0
-    [GitFmtChanges]
     [InstallGuide]
     [ReadmeFromPod]
     [ExtraTests]
@@ -184,6 +193,7 @@ this:
     [Twitter]
     [ArchiveRelease]
     [InstallRelease]
+    [NextRelease]
 
 =for Pod::Coverage configure
 
